"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
exports.networkRefreshTokenHandler = void 0;
const axios_1 = __importDefault(require("axios"));
const axios_retry_1 = __importDefault(require("axios-retry"));
const ax = axios_1.default.create({
    baseURL: (!window && ((_a = process === null || process === void 0 ? void 0 : process.env) === null || _a === void 0 ? void 0 : _a.TOKEN_BASE_URL)) || 'http://localhost:8080',
    timeout: 20000,
});
(0, axios_retry_1.default)(ax, {
    retryDelay: () => 1000,
    retries: 9,
    retryCondition: (error) => {
        var _a;
        if (((_a = error.response) === null || _a === void 0 ? void 0 : _a.status) !== 404) {
            return true;
        }
        return false;
    },
});
/**
 * Network refresh token storage handler.
 * Compliant with <strong><em>/api/setdata</em></strong> and <strong><em>/api/getdata</em></strong> endpoints of Kiosk Local Service.
 */
exports.networkRefreshTokenHandler = {
    setRefreshToken(tenant, refreshToken) {
        return ax
            .post('/api/setdata', {
            createdAt: Date.now(),
            updatedAt: Date.now(),
            name: `${tenant}_refresh_token`,
            value: refreshToken,
        }, {
            'axios-retry': {
                retries: 3,
            },
        })
            .then(() => {
            return;
        })
            .catch((err) => {
            console.error('error saving refresh token', err);
            return;
        });
    },
    getRefreshToken(tenant) {
        return ax
            .post('/api/getdata', { name: `${tenant}_refresh_token` })
            .then(({ data }) => data.value)
            .catch((err) => {
            console.error('error getting refresh token', err);
            return '';
        });
    },
    clearRefreshToken(tenant) {
        return ax
            .post('/api/setdata', {
            createdAt: Date.now(),
            updatedAt: Date.now(),
            name: `${tenant}_refresh_token`,
            value: '',
        }, {
            'axios-retry': {
                retries: 3,
            },
        })
            .then(() => {
            return;
        })
            .catch((err) => {
            console.error('error removing refresh token', err.message, err);
            return;
        });
    },
};
