var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import axios from 'axios';
import { getErrorMessage } from '../utils';
import { networkRefreshTokenHandler } from '../refreshTokenHandler';
import { http, HttpResponse } from 'msw';
import { setupServer } from 'msw/node';
const tenant = '8724ef16-20c8-4008-b183-3504cedc38af';
const api = axios.create({
    baseURL: 'https://ordering.3e.pl',
    headers: {
        Authorization: 'Basic b3JkZXJpbmdrZHNzaG9ydDpjTDlCZ21zcmZXM3VKSGQ1MEk=',
        'X-Tenant': tenant,
        'Content-Type': 'application/x-www-form-urlencoded',
    },
});
const VALID_MODULE = 'kds-test'; // module with user
describe('Device Code Error Handler', () => {
    it('should return error kind "INVALID_MODULE" if invalid module id was provided', () => __awaiter(void 0, void 0, void 0, function* () {
        try {
            yield api.post('/auth-oauth2/oauth/device', {
                module: 'invalid-module',
            });
        }
        catch (e) {
            const err = getErrorMessage(e);
            console.log(err);
            expect(err.message).not.toBe(undefined);
            expect(err.kind).toBe('INVALID_MODULE');
        }
    }));
});
describe('Network Refresh Token Handler', () => {
    it('Tries /api/getdata 10 times if gets non 404 error', () => __awaiter(void 0, void 0, void 0, function* () {
        const callback = jest.fn();
        const server = setupServer(...[
            // Intercept "GET https://example.com/user" requests...
            http.post('http://localhost:8080/api/getdata', () => {
                callback();
                return new HttpResponse('Internal error', { status: 500 });
            }),
        ]);
        server.listen();
        yield networkRefreshTokenHandler.getRefreshToken('test');
        expect(callback).toHaveBeenCalledTimes(10);
        server.close();
    }), 12000);
    it('Tries /api/getdata 1 time if gets 404 error', () => __awaiter(void 0, void 0, void 0, function* () {
        const callback = jest.fn();
        const server = setupServer(...[
            // Intercept "GET https://example.com/user" requests...
            http.post('http://localhost:8080/api/getdata', () => {
                callback();
                return new HttpResponse('Not found', { status: 404 });
            }),
        ]);
        server.listen();
        yield networkRefreshTokenHandler.getRefreshToken('test');
        expect(callback).toHaveBeenCalledTimes(1);
        server.close();
    }), 4000);
});
